package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`"``!````4!A``#0```!PI@``!Q``$#0`(``+
M`"@`'P`>``8````T````-`!``#0`0`!@`0``8`$```4````$`````P```)0!
M``"4`4``E`%```T````-````!`````$````#``!PR`$``,@!0`#(`4``&```
M`!@````$````"````````'#@`0``X`%``.`!0``8````&`````0````$````
M`0```````````$````!``.2;``#DFP``!0```````0`!````])\``/2?00#T
MGT$`K`$``-P1```&```````!``(````<`@``'`)``!P"0``H`0``*`$```0`
M```$````!````*0!``"D`4``I`%``"`````@````!`````0````$````^`$`
M`/@!0`#X`4``)````"0````$````!````%+E=&3TGP``])]!`/2?00`,````
M#`````0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````!````!`````!````1TY5```````"````!@```"``
M```````````"``$!``$`````````````````````]@$`L@``````````````
M```````P($(`!````!0````#````1TY5`&,+IJL2>C@JD0'J-@%KAAZ%1A3[
M`0```)P#```!````QP,```$```#2`P```0```-P#```!````_@,```$````A
M!````0```"D$```,````!!5```T```#06T``&0```/2?00`;````!````!H`
M``#XGT$`'`````0````$````1`-```4```"X#4``!@```)@&0``*````N`4`
M``L````0````%@``<#"@00`5``````````,```!`H$$``0``<`$````%``!P
M`@````8``'```$``"@``<`H````1``!P<@```!(``'`>````$P``<"4```#^
M__]O5!1``/___V\#````\/__;W`30```````````````````````````````
M``````````````````````````````````!A````<@``````````````````
M`"T``````````````#8`````````00```"H```!3`````````$T```!4````
M#0````````!>````&@````(````P````"````!````!"````,P``````````
M````7P```!0````I```````````````D````'@```$,````T`````````!8`
M```C`````````#H`````````.``````````<````%0```!$````G````````
M```````;````7````$L```!7```````````````8````3@```#X```!*````
M``````````!G`````````$8`````````(@``````````````:@```"@````K
M````,0```$D````L```````````````!````"@```$4```!M````+P````\`
M```Y`````````"4````A```````````````2````%P````````!$````'P``
M`$<````F````-0```#\```````````````````````````````````!L````
M````````````````;@```````````````````%8```!K````"0````P`````
M`````````$@````3`````P```````````````````!D`````````3````&4`
M``!A`````````#<``````````````&0````[````0``````````@````4```
M`#(``````````````"X``````````````!T```!F````<0````````!5````
M`````#T`````````3P`````````\````60``````````````:0```%(`````
M````````````````````#@`````````'````6`````````!H````"P```%$`
M````````;P````````!B``````````````!@````````````````````````
M`%H```!;````70````````````````````````````````````````!C````
M<```````````````!`````````````````````8`````````````````````
M````!0``````````````````````````````````````````````$0```+17
M0``(````$@`-`&,$``!T.4``"````!(`#0"L`P```0`````````3`/'_PP0`
M``"@00``````(0`5`!<$`````````````!$```!T!```D$!``%`````2``T`
MCP0``*A50`"\````$@`-`$4$``"@H4$``````!``&``;````T%M````````2
M``\`FP0``/P[0``X````$@`-`*@$```T/$``C`$``!(`#0"T!```M$)``'0-
M```2``T`P00```"@00``````$0`5``@$````7$``!````!$`$``^!````*!!
M```````0`!4`S@0``'0X0````0``$@`-`+T#```PH$$``````!$`%@`!````
M$%=``*0````2``T`Y`0``""@00`$````$0`5`%X$``#0L4$``````!``&0#T
M`@``X%9``#`````2`@T`[@0``,`]0``L`@``$@`-`$P$``"@H4$``````!``
M&0#[!```I#=``%`````2``T`+@```$`50``0`P``$@`-``,%```P($(`````
M`!,`\?\,!0``4!A````````2``T`%`4`````````````$0```",%``!\.4``
M@`(``!(`#0`P!0``X$!``-0!```2``T`0@4``.P_0`"D````$@`-`%`%``!D
M5D``=````!(`#0`W!```0!5````````0``T`6`0``*"A00``````$``9`/T$
M```$%4```````!(`#`!L!0``*%!``(`%```2``T`X````+!;0```````$@``
M`,X```"@6T```````!(```#_````D%M````````2````.@(``(!;0```````
M$@```#H!``!P6T```````!(````9`0``8%M````````2````[@```%!;0```
M````$@```!D$`````````````!$```"O````0%M````````2````7@``````
M````````(````+L"```P6T```````!(```#Z`0``(%M````````2````U@``
M`!!;0```````$@```'\#````6T```````!(```!<`0``\%I````````2````
M>```````````````(`````,#`````````````!(```!7`@``X%I````````2
M````N@$``-!:0```````$@```$4!``#`6D```````!(```"4`0``L%I`````
M```2````/P,``*!:0```````$@```-$!``"06D```````!(```"A`@``@%I`
M```````2````8@,``'!:0```````$@```%4!``!@6D```````!(````(`@``
M4%I````````2````X0(`````````````$@```,@!``!`6D```````!(```#M
M`0``,%I````````2````0`(``"!:0```````$@```(D!```06D```````!(`
M``",`@```%I````````2````+0$``/!90```````$@```!D"``#@64``````
M`!(````A````T%E````````2````MP```,!90```````$@```-("``"P64``
M`````!(```"S`0``H%E````````2````B`,`````````````$0```)<#``"0
M64```````!(````S```````````````B````+0(``(!90```````$@```$<"
M``!P64```````!(````X`P``8%E````````2````O@```%!90```````$@``
M`"P#``!`64```````!(```"E`0``,%E````````2````(`(``"!90```````
M$@```.P#```064```````!(```"M`@```%E````````2````(0,``/!80```
M````$@```&4"``#@6$```````!(```!K`0``T%A````````2````3`$``,!8
M0```````$@```(4"``"P6$```````!(````4`P`````````````1````2@,`
M`*!80```````$@```/@```"06$```````!(````.`0`````````````1````
MWP$``(!80```````$@```)X```!P6$```````!(```!8`P``8%A````````2
M````<`,``%!80```````$@````@!``!`6$```````!(```!Y`0``````````
M```2````=P(``#!80```````$@```(P``````````````!$```"L`0``(%A`
M```````2````70,``!!80```````$@```,8`````6$```````!(```#S`0``
M```````````1````A@0``/!70```````$@```$(``````````````"`````H
M`@``X%=````````2````P0$``-!70```````$@```.8!``#`5T```````!(`
M````7U]L:6)C7V-S=5]I;FET`%]?;&EB8U]C<W5?9FEN:0!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?2G9?4F5G:7-T97)#
M;&%S<V5S`%]?<W1A8VM?8VAK7V=U87)D`%]?<W1A8VM?8VAK7V9A:6P`<W1R
M;F-M<`!S=')L96X`<F5A;&QO8P!M96UM;W9E`&]P96YD:7(`<F5A9&1I<C8T
M`%]?<W!R:6YT9E]C:&L`7U]X<W1A=#8T`'5N;&EN:P!C;&]S961I<@!R;61I
M<@!03%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`4&5R;%]N97=35G!V
M`%]?;'AS=&%T-C0`86-C97-S`')E861L:6YK`&UE;6-H<@!097)L7W-V7W-E
M='!V;@!097)L7W-V7W-E='!V`&)O;W1?1'EN84QO861E<@!097)L7VYE=UA3
M`%!E<FQ?;F5W6%-?9FQA9W,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R=&]K
M`'-T<F-M<`!?7W-T<F1U<`!?7W-T<FYC<'E?8VAK`&=E='5I9`!S=')S='(`
M;6MD:7(`<W1D97)R`%]?9G!R:6YT9E]C:&L`7U]E<G)N;U]L;V-A=&EO;@!O
M<&5N-C0`;'-E96LV-`!R96%D`%]?;65M8W!Y7V-H:P!C;&]S90!M96US970`
M4&5R;%]G=E]F971C:'!V`%!E<FQ?879?9F5T8V@`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%]A=E]S:&EF=`!E>&5C=G``4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M4&5R;%]M9U]S970`4&5R;%]D;W5N=VEN9`!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!P=&AR96%D
M7V%T9F]R:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N9'5M<`!P97)L7V%L
M;&]C`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U
M8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]C;VYS=')U8W0`<&5R
M;%]R=6X`4$Q?;65M;W)Y7W=R87``97AI=`!L:6)P97)L+G-O+C4N,C``7T19
M3D%-24-?3$E.2TE.1P!?7U),1%]-05``;&EB9&PN<V\N,@!L:6)M+G-O+C8`
M;&EB<'1H<F5A9"YS;RXP`%]?<F5G:7-T97)?871F;W)K`&QI8F,N<V\N-@!?
M24]?<W1D:6Y?=7-E9`!?7V5N=FER;VX`;&0N<V\N,0!L:6)C<GEP="YS;RXQ
M`%]F=&5X=`!?9F1A=&$`7V5D871A`%]?8G-S7W-T87)T`%]F8G-S`%]E;F0`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`;7E?<&%R
M7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`%]G<%]D:7-P`%]?<W1A<G0`7U]G
M;G5?;&]C86Q?9W``<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A
M<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`1TQ)0D-?,BXR`$=,24)#7S(N
M,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@````$``0`!``$``@`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!`````0`!``$`
M`0`!``$``0`!``@``@`"``,`"0`#``D``@`"```````(``D`````````````
M``(``@``````"````````@`#`````@`"``(`````````!P`"``(````"````
M`@````@````"``(````"``<`!@````````````(``@```````@````(`!0``
M`````@``````!``"``(``@`"``(````#``(``@`!``$`(00``!`````@````
M%&EI#0``!`""!0````````$``@#<`P``$````#`````2:6D-```'`(P%```0
M````$&EI#0```P"6!0````````$`!0#^`P``$``````````2:6D-```)`(P%
M```0````=!EI"0``"`"@!0``$````'(9:0D```8`K`4``!`````4:6D-```%
M`((%```0````$&EI#0```@"6!0````````(`'#PL"YPG(>"9`^#_O2<0`+RO
M'`"_K]R`@H\$`$`0)0@@`-R`F8\)^"`#)0@@`!P`OX\(`.`#(`"])T(`'#RX
M_[TG,""<)S``L*]$@9"/1`"_KQ@`O*]``+2O/`"SKS@`LJ\T`+&O```"CLR`
MF8](`*2O)`"EKR``IJ](`*0G)`"E)R``IB<L`**O"?@@`R4((``8`+R/I("%
MCR2`F8]X@(2/"?@@`R$PH``8`+R/&(&"CP``0I!L`$`0!(&9CR2!D8],@)F/
M"?@@`P``)(ZV`T.0&`"\CP(`8S1,@)F/```DC@GX(`.V`T.@2`"DC[8#0Y`%
M`(0D`!"$1`$`8S08`+R/M@-#H&\`@`0A$(!&`!"`1$$``CP`&(!$)0@@````
M(D;8FT+4/!`@1B4((`!Q``%%\("9CPGX(`.`(`0`)`"HCQ@`O(\```.-0@`$
M/```0ZQ```,\B%]C)""@A8Q(`*:/!`!#K$```SR,7V,D0@`'/`@`1:P,`$.L
M!``%)$(``SP"`,0HM+'BK`H`@!2XL66L@#@&`/S_YR0A&```(2`#`00`A8PA
M($,`!`!C)/O_9Q00`(6L@!@&`$(`$3R,@)F/(1A#`,"Q)(Y```4\#`!@K/0W
MI200`*"O`P#&)`GX(`,A.$``(9!``#``0!`8`+R/'(&9C\"Q)(X)^"`#*`"S
M)T``!#S(7(0D10L0#"$H8`(P`$`0&`"\CS"!F8\)^"`#P+$DCA@`O(^8@)F/
M"?@@`R4((``L`*2/```#CA@`O(\[`(,4(1!``D0`OX]``+2//`"SCS@`LH\T
M`+&/,`"PCP@`X`-(`+TG"?@@`R4((`!"``,\&`"\CS``0!#`L6*L-(&9CR2!
MD8\)^"`#(2!``!@`O(],@)F/"?@@`P``)(X8`+R/<@40"`4&0*!L@)F/"?@@
M`\"Q)(XAD$``O@40"!@`O(]!``(\T)M"U(4%$`@``")&0@`4/+RQA(X*`(`0
M)0@@`&H5$`PE""``R`40"!@`O(]```0\U("%C[B`F8\)^"`#9%Z$)$``!#QD
M7(0D10L0#"$H8`(A($``&`"\C[W_0!"\L8*N^P40""4((``L@9F/"?@@`R4(
M(`#8@)F/"?@@`P$`!"0A`.`#`0`1!"4((`!"`!P\,""<)R'X```8@(2/``"E
MCP0`IB?X_P$D).BA`^#_O2<<@(>/(("(CQ``J*\4`**O&`"]K\2`F8\)^"`#
M)0@@`/__`!`E""``)0@@`"4((`!"``0\0@`"/#2@A"0WH$(D(Q!$``<`0BP'
M`$`40@`</#`@G"=<@9F/`P`@$R4((``(`"`#)0@@``@`X`,E""``0@`$/$(`
M`CPTH(0D-*!")",01`"#$`(`PB\"`"$HH@!#*`4`!P"@$$(`'#PP()PG7("9
MCP,`(!,E""``"``@`R4((``(`.`#)0@@`.#_O2<8`+"O0@`0/*"A`I(%`$`4
M'`"_KRP&$`PE""```0`")*"A`J(<`+^/&`"PCP@`X`,@`+TG0@`$//R?A"0`
M`(*,`P!`%$(`'#P\!A`()0@@`.#_O2<P()PG=("9CQP`OZ\0`+RO!0`@$QP`
MOX\)^"`#)0@@`!``O(\<`+^//`80""``O2<E""``)0@@`"4((`!"`!P\,""<
M)U#]O2=$@8R/K`*_KZ@"L:^D`K"O$`"\KP``@HTX`(LDG`*BKQ@`JB=X`(XD
M_P`-/```:8T$`&B-`#H)```J"``",@D``'X)```>"``D..T``A((`"0HK0`E
M**,``/]","4X[P``_\8P)1BB`"4PY@`"3@D``A8(`"4HR0`E$&(`"`!K)0``
M1:T$`$"M"`!"K0P`0*WF_VX5$`!*)8``HB>``JTGV/]#C```2XS<_T:,!`!*
MC*C_28RL_TB,F/]%C)S_1XPF&&L`)C#*`"88(P$F,`8!)ABC`"8PY@#"+P,`
M0#`&`"4HQ0!`&`,`)1BC`!@`0ZP<`$"L"`!").G_3108`*./``"&C`0`C8P(
M`(>,(`"*C!``B(P8`(F,0%D-``P`CXS"+@8`@EH"/)EY0B1`@08`)2AE`2$8
M0P$G6`<`)2BP`(!_#P`D@`<!(1AB`"18:0&"<`<`)7#N`2$890"`?P<`)2AP
M`2``JX\E>,\!)\`&`"$H90`DP`@#)!CF`2%8*P$EP'@`PH8%`"%88@%`&04`
M(5AX`8!O#0""<`8`)1@#`B$88P$E<*X!*`"KCX!O!@`E<,T!)V@%`"1HKP$D
M@*X`(5@+`2%88@$E@+`!PL8#`$")`P"":`4`@"\%`"7(I0$A*'`!)5@1`R$H
MJP`P`*N/)V@#`"2`>0`A6&(!)&BN`2%X;P$E:+`!PL8%`$!9!0""@`,`@!\#
M`"6``P(E6`L#(1CM`2$8:P`X`*N/)V@%`"1XL``A6&(!)&BY`2%P;@&"P`4`
M)5BO`8`O!0#";@,`0'D#`"7`!0,E**\!0`"MCR%PRP$G6`,`(2C%`2%HH@$D
M<'@`)%AP`258;@$A:+D!PG8%`$")!0`A:*L!@G@#`$@`JX^`'P,`)7CC`248
MT0$G<`4`(1BC`2%88@$D:-@!)'"O`"5HK@%`B0,`PG8#`"%8<`&"@`4`@"\%
M`"6`!0(A6&T!)2C1`2$H90%0`*N/)V@#`"1P<``A6&(!)&BO`4")!0`AP'@!
M)5BN`<)N!0""<`,`@!\#`"5PPP$E&+$!6`"MCR'`"P,G6`4`)(BN`"%HH@$D
M6'`!(1@#`R%XKP$E6'$!@F@%`(`O!0`ER*4!PL8#`"%HZP%`B0,`8`"KCR4H
M$0,G>`,`(2BE`2%88@$D:.X!)'AY`"&`<`%`B04`)5BO`<)N!0"">`,`@!\#
M`"5XXP$A6`L")1BQ`2$88P%H`*N/)V@%`"2`KP`A6&(!)&BY`2%P;@&"P`4`
M)5BP`8`O!0#";@,`0($#`"7`!0,E*+`!<`"MCR%PRP$G6`,`(2C%`2%HH@$D
M<'@`)%AO`258;@$A:+D!PG8%`$")!0`A:*L!@H`#`'@`JX^`'P,`)8`#`B48
MT0$G<`4`(1BC`2%88@$D:-@!)'"P`"5HK@%`B0,`PG8#`"%8;P&">`4`@"\%
M`"5XY0$A6&T!)2C1`2$H90&``*N/)V@#`"1P;P`A6&(!)&BP`4")!0`AP'@!
M)5BN`<)N!0""<`,`@!\#`"5PPP$E&+$!B`"MCR'`"P,G6`4`)(BN`"%HH@$D
M6&\!(1@#`R&`L`$E6'$!@F@%`(`O!0`EP*4!PLX#`"%H"P)`B0,`D`"KCR4H
M,0,G@`,`(2BE`2%88@$D:`X")(!X`"%X;P%`B04`)5BP`<)N!0""@`,`@!\#
M`"6``P(A6.L!)1BQ`2$88P&8`*N/)V@%`"1XL``A6&(!)&BX`4")`P`A<&X!
M)5BO`<)N`P"">`4`@"\%`"5XY0$E*+$!H`"MCR%PRP$G6`,`(2C%`2%HH@$D
M<&\`)%AP`258;@$A:+@!0(D%`,+&!0`A:*L!@G`#`*@`JX^`'P,`)7##`248
M$0,GP`4`(1BC`22(K@`D:`\#(5AB`2%8<`$E@+$!PL8#`"%8<`%`:0,`L`"P
MCX+(!0"`+P4`)<@E`R5H#0,G*`,`(6AM`2$0`@(D**X`)%AY`"58JP`A>$\`
MPH8-`"%XZP%`*0T`@L`#`+@`JX^`'P,`V6X"/*'K0C0EP`,#)2@%`B$HY0$A
M6&(!)G@9`R9X[0'"'@4`0(D%`"%P;@&"@`T`@%\-`,``K8\E@`L"(7#/`258
M<0`A6,L!)A@8`B%HH@'"=@L`@H@%`"%HN0&`?P4`)LAE`$`9"P#(`*6/)7@O
M`B%HN0$E&,,!(1BC`2$HH@`F:/`!0(D#`"$HN``FP*L!PFX#`(+("P"`=PL`
M(2BX`"58L0$A**L`T`"KCR5P+@,FP,\!(5AB`2;``P."B`,`(5AP`4#)!0#"
MA@4`@&\#`-@`HX\E:"T"(5AX`27(&0(AR'D!(1AB`"98K@%`@1D`(1AO`(+`
M!0`F>&4!PEX9`(`O!0`EP`4#)2AP`>``JX\A&&\`(2AE`"%88@$F>`T#PAX%
M`$")!0`A<&X!@H`9`(!?&0`E@`L")GCY`258<0#H`*./(7#/`2%8RP$A&&(`
M)L@8`B;()0/"=@L`0(D+`"%H;0"">`4`@!\%`/``I8\E>.,!(6BY`248T0$A
M&*,!(2BB`"9H\`%`B0,`(2BX`";`JP'";@,`@L@+`(!W"P`A*+@`)5BQ`2$H
MJP#X`*N/)7`N`R;`SP$A6&(!)L`#`X*(`P`A6'`!0,D%`,*&!0"`;P,```&C
MCR5H+0(A6'@!)<@9`B'(>0$A&&(`)EBN`4")&0`A&&\`@H`%`"9X90'"7AD`
M@"\%`"6`!0(E*'$!"`&KCR$8;P`A*&4`(5AB`29X#0(F>/D!0(D%`"%P;@'"
M'@4`)1AQ`"%PSP$A<,,!@%\9`(+`&0`0`:./)<`+`R$88@`FR!`#)L@E`R%H
M;0"">`4`@!\%`!@!I8\E>.,!PEX.`$")#@`E&'$!(6BY`298^`$A**(`(6BC
M`298;@$A*+``0(D-`,(>#0`A**L`(`&KCR48<0""@`X`@'<.`"$HHP`E@`X"
M(5AB`2;(#P+"'@4`(5AX`4#!!0`FR"T#@G`-`"7`>`"`;PT`*`&CCR5PS0$A
M6'D!(<!X`29HT`$A&&(`)FBE`<)>&`!`B1@`(1AO`()X!0"`+P4`)7CE`24H
M<0$P`:N/(1AM`"$H90`A6&(!)LCN`2;(.`-`B04`(8!P`<(>!0`E&'$`(8`9
M`B&``P*`7Q@`@F@8`#@!HX\E:*L!(1AB`";`KP$FP`4#PEX0`$")$``A<&X`
M@L@%`(`?!0`A<-@!)2AQ`2%PQ0%``:6/)1@C`R$HH@`FP&T`(7BO`";`$`-`
MB0X`@B@0`,)>#@"`AQ``)8"P`"58<0$A*/@!(2BK`$@!JX\FP`,"(5AB`2%H
M;0$FP`X#@E@.`(!W#@`ER&X!PGX%`$")!0`A6+@!4`&MCR5P\0$A6&X!(1"B
M`8!W!0`F:#`#@L`%`"7`#@,F**4!0'$+`,)N"P`A&$,`(1AE`"4HK@$A&&4`
M&X\"/%@!I8_<O$(T)6@9`R2(&0.`=PL`(2BB`"1H;0&">`L`)7CN`258L0%`
M<0,`PFX#`"$HL``A**L`)5BN`2$HJP!@`:N/)7#X`22(^`$A6&(!)'!N`(!O
M`P""@`,`(5AY`248T0$E@`T"0'$%`"%88P'";@4`:`&CCR5HK@$E<`\"(6AM
M`2$88@`D6*X`)'`/`H*(!0`E6&X!(1AX`(`O!0`E*"4"PG8-`"$8:P!`P0T`
M<`&KCR7(L``EP-@!(<!X`"2(L``A<&(!)!BY`248<0""R`T`@%\-`"%PSP$E
M6"L#PFX8`"%PPP%`>1@`>`&CCR7(90$E>*\!(7C/`22(90$A:&(`)'`9`R5P
MT0$A:+`!0(D/`,*&#P""R!@`(6BN`8`?&``E<!$")1@C`R%PK@&``:V/)8!K
M`"2(:P`A:*(!)(#P`8+`#P`A**4!@'\/`"5H$0(EP`\#0($.`,)^#@`A**T`
MB`&MCR6`\`$E>`,#(2BP`"%HH@$D@`,#)'C/`8+(#@"`=PX`)<@N`R%8JP'"
M=@4`)6CP`4!Y!0`A6&T!)6C/`2%8;0&0`:V/)7`X`R1X.`,A:*(!)'"N`(*(
M!0"`AP4`(1BC`24HSP'";@L`0'$+`"$890`E**X!(1AE`"6`,`*8`:6/)6@9
M`B2(&0*`=PL`(2BB`"1H;0&">`L`)7CN`258L0%`<0,`PFX#`"$HN``A**L`
M)5BN`2$HJP"@`:N/)7#P`22(\`$A6&(!)'!N`(!O`P""P`,`(5AY`248T0$E
MP`T#0'$%`"%88P'";@4`J`&CCR5HK@$E<`\#(6AM`2$88@`D6*X`)'`/`X*(
M!0`E6&X!(1AP`(`O!0`E*"4"PG8-`"$8:P!`@0T`L`&KCR7(N``E@-`!(8!P
M`"2(N``A<&(!)!BY`248<0""R`T`@%\-`"%PSP$E6"L#PFX0`"%PPP%`>1``
MN`&CCR7(90$E>*\!(7C/`22(90$A:&(`)'`9`B5PT0&"R!``0(D/`(`?$``A
M:+@!PH8/`"%HK@$E<!$")1@C`R%PK@'``:V/)<!K`"2(:P`A:*(!),#X`8*`
M#P"`?P\`)8`/`B$HI0'"?@X`)6@1`T")#@`A**T`)6CQ`2$HK0#(`:V/)7@#
M`B2(`P(A:*(!)'C/`8+(#@"`=PX`)<@N`R%8JP'"=@4`)6CQ`4!Y!0`A6&T!
M)6C/`2%8;0'0`:V/)7`P`R2(,`,A:*(!)'"N`(!_!0""P`4`(1BC`24HT0'"
M;@L`0'$+`"$890`E**X!(1AE`"7`#P/8`:6/)6@9`R1X&0,A**(`)&AM`8*(
M"P"`=PL`(2BP`"58KP'";@,`0'D#`"$HJP`E6*\!)7`N`B$HJP#@`:N/)7C8
M`22`V`$A6&(!)'AO`(*(`P"`;P,`(5AY`248\`$E:"T"PGX%`"%88P%`R04`
MZ`&CCR7(^0$E>*X!(<AY`22`K@$D6*\`(1AB`()X!0"`+P4`)7CE`2$8>``E
M*'`!PEX9`$"!&0`A&&4`)2AP`?`!JX\E@.T!(2AE`"$08@$D&#`#)%CM`248
M:P`A<$X`PL8%`$")!0"`7QD`(7##`8*`&0!BR@(\^`&CC];!0C0E@`L")5@1
M`R%8RP$A&&(`)L@/`B;()0/"=@L`0(D+`"%H;0""P`4`@!\%```"I8\EP`,#
M(6BY`248T0$A&*,!(2BB`"9H$`-`B0,`(2BO`"9XJP'";@,`@L@+`(!W"P`A
M**\`)5BQ`2$HJP`(`JN/)7`N`R9HV`$A6&(!PGX%`(*(`P`A6'`!0,D%`":`
MHP&`;P,`)6@M`B%8<`$ER/D!$`*CCR'(>0$F@*X!)H`%`L)>&0!`B1D`(1AB
M`()X!0"`+P4`)7CE`2$8>``E*'$!&`*KCR$8<``A*&4`(5AB`2;`[0'"'@4`
M0(D%`"%P;@&"@!D`@%\9`"6`"P(FP!D#)5AQ`"`"HX\A<-@!(5C+`2$88@`F
MR`\")L@E`\)V"P!`B0L`(6AM`(+`!0"`'P4`*`*ECR7``P,A:+D!)1C1`2$8
MHP$A**(`)F@0`T")`P`A**\`)GBK`<)N`P""R`L`@'<+`"$HKP`E6+$!(2BK
M`#`"JX\E<"X#)FC8`2%88@'"?@4`@H@#`"%8<`%`R04`)H"C`8!O`P`E:"T"
M(5AP`27(^0$X`J./(<AY`2:`K@$F@`4"PEX9`$")&0`A&&(`@G@%`(`O!0`E
M>.4!(1AX`"4H<0%``JN/(1AP`"$H90`A6&(!)L#M`<(>!0!`B04`(7!N`8*`
M&0"`7QD`)8`+`B;`&0,E6'$`2`*CCR%PV`$A6,L!(1AB`";(#P(FR"4#PG8+
M`$")"P`A:&T`@L`%`(`?!0!0`J6/)<`#`R%HN0$E&-$!(1BC`2$HH@`F:!`#
M0(D#`"$HKP`F>*L!PFX#`(+("P"`=PL`(2BO`"58L0$A**L`6`*KCR5P+@,F
M:-@!(5AB`<)^!0""B`,`(5AP`4#)!0`F@*,!@&\#`"5H+0(A6'`!)<CY`6`"
MHX\AR'D!)H"N`2:`!0+"7AD`0(D9`"$88@"">`4`@"\%`"5XY0$A&'@`)2AQ
M`6@"JX\A&'``(2AE`"%88@$FP.T!PAX%`$")!0`A<&X!@H`9`(!?&0`E@`L"
M)L`9`R58<0!P`J./(7#8`2%8RP$A&&(`)L@/`B;()0/"=@L`0(D+`"%H;0""
MP`4`@!\%`'@"I8\EP`,#(6BY`248T0$A&*,!(2BB`"9H$`-`B0,`(2BO`"9X
MJP'";@,`@L@+`(!W"P`A**\`)5BQ`2$HJP"``JN/)7`N`R9HV`$A6&(!PGX%
M`$#)!0`A6'`!)H"C`8*(`P"`;P,`(5AP`248^0$A6&,!B`*CCR5H+0(F@*X!
M(1AB`":`!0(A&'@`PGX+`$#!"P`A&'``)7CX`2%X;P""R`4`D`*CCX`O!0`E
M*"4#(1!B`"88K0`A$$X`0($/`"9P:P#"'@\`)1AP`"$03@`A$$,`(3!&`((8
M"P"`%PL```"&K"408@"<`JN/``"&C2$8YP$A0$@`(2BI`"%HJ@$$`("L"`"#
MK`P`@*P0`(BL%`"`K!@`A:P<`("L(`"-K`8`9A4D`("LK`*_CZ@"L8^D`K"/
M"`#@`[`"O2<L@9F/"?@@`R4((`!,`(`00@`</#`@G"?(_[TG5(""CS0`OZ\P
M`+:O+`"UKR@`M*\D`+.O(`"RKQP`L:\8`+"O$`"\KP``58PD`*`2)0@@````
M@H`,`$`0(9```#T``R0)`$,0)0@@`"&0@``!`%(F``!"@@,`0!`E""``^_]#
M%"4((``CD$0"``"PCA,``!(AF*``(:"``"&(H`(]`!8D6("9CR$@``(A*(`"
M"?@@`R$P0`(0`+R/!`!`%"$8$@(``&*`$`!6$`$`0B8$`#$F```PCO/_`!98
M@)F/-`"_CS``MH\L`+6/*`"TCR0`LX\@`+*/'`"QCQ@`L(\A$```"`#@`S@`
MO2<CB#4"@X@1````<:XT`+^/(1`"`C``MH\L`+6/*`"TCR0`LX\@`+*/'`"Q
MCQ@`L(\(`.`#.`"])P@`X`,A$```0@`</,C_O2<P()PG+`"RKT2!DH\P`+.O
M*`"QKR0`L*\T`+^O$`"\KP``0HY4@)&/(8"``!@`LR<<`**O(2```D4+$`PA
M*&`"$0!`$!``O(\8`**/@!@"````(HXA$$,`!`!#C/7_8!```$.L!`!")`0`
M0XS]_V`4``!#K"$@``)%"Q`,(2A@`O'_0!00`+R/'`"CCP``0HX'`&(4-`"_
MCS``LX\L`+*/*`"QCR0`L(\(`.`#.`"])RR!F8\)^"`#)0@@`$(`'#RX_[TG
M,""<)RP`LJ]$@9*/*`"QKR0`L*]$`+^O0`"WKSP`MJ\X`+6O-`"TKS``LZ\0
M`+RO``!"C@``HX`<`**O/0`")"&`H`!@`&(0(8B``,B`F8\)^"`#(2```B$@
M(`(8`*4G10L0#"&@0``AF$``6`!`$!``O(_(@)F/"?@@`R$@0``K$%0`1`!`
M$!``O(\8`+./5("6CX"H$P```"*"#0!`$"$8```]``,D=@!#$#T`!R3W"Q`(
M(1@@`@4`IQ`E""```0!C)```98#[_Z`4)0@@`",8<0#H@)F/``#"C@(`A"8A
M((,`"?@@`R&850`0`+R/:0!`$```8JY4@(*/`0`D)@``0XP8`**/@!`"`"$0
M8@```$.,```B@@@`0!```&*@/0`%)`4`11`!`(0D__^"@`$`8R3[_T`4``!B
MH#T`!"0!`&(D``!DH`$`$";__P."`0!")/S_8!3__T.@(1```!P`I(\``$..
M30"#%$0`OX]``+>//`"VCS@`M8\T`+2/,`"SCRP`LH\H`+&/)`"PCP@`X`-(
M`+TG`0`0)O__`H(!`',F[?]`$/__8J(!`!`F__\"@@$`<R;W_T`4__]BHA\,
M$`@A$```V@L0"`$`L"14@):/``#7C@``XHXK`$`0(1#@`B$8```$`$(D``!&
MC/W_P!0!`&,D`@!E)"&88`"`*`4`0@`"/+"Q0XP.`&`0Z("9C^R`F8\)^"`#
M(2#@`A``O(\<`$`0``#"KH"H$P`!`&,F@!@#`"$00P```$"L[0L0"!@`LZ\!
M``,D(2"@``GX(`.PL4.L#P!`$!``O(]0@9F/@*@3`"$@0``A*.`""?@@`R$P
MH`(0`+R/4PP0"```PJ[\"Q`((1@```@`!21(#!`((9@``!\,$`C__P(D+(&9
MCPGX(`,E""``0@`</!#_O2<P()PGU`"SKT2!DX_,`+&O[`"_K^@`OJ_D`+>O
MX`"VK]P`M:_8`+2OT`"RK\@`L*\8`+RO``!BCB&(@`#$`**O!`"`$"4((```
M`(*`$`!`%#R`F8_$`*./``!BCF@`8A3L`+^/Z`"^C^0`MX_@`+:/W`"UC]@`
MM(_4`+./T`"RC\P`L8_(`+"/"`#@`_``O2<)^"`#)0@@`"&00`#M_T`0&`"\
MCT``%3PN`!0D!%RU)B``OB<`0!8D:("9CPGX(`,A($`"(8!``#8`0!`8`+R/
M$P`"DCP`5!#(@)F/"?@@`R$@(`(8`+R/$P`0)LB`F8\A(``""?@@`R&X0``8
M`+R/(1#B`NB`F8\)^"`#`@!$)!@`O(\A($``.("9CP$`!23__P8D(3B@`A``
ML:\4`+"O"?@@`R&X0``8`+R/`P`$)%"`F8\A*.`""?@@`R$PP`/__P,D!0!#
M$!@`O(\X`**/`/!","(`5A`E""``((&9CPGX(`,A(.`"&`"\CTR!F8\)^"`#
M(2#@`A@`O(]H@)F/"?@@`R$@0`(A@$``S/]`%!@`O(]`@)F/"?@@`R$@0`(8
M`+R/.(&9CPGX(`,A("`"B0P0"!@`O(\4``*2N_]`$&B`F8_!_U04R("9CQ4`
M`I*U_T`0)0@@`*L,$`@E""``<@P0#"$@X`+3#!`(&`"\CRR!F8\)^"`#)0@@
M`$(`'#S8_[TG,""<)Q@`L*\D@9"/)`"_KR``LJ\<`+&O$`"\KTR`F8\)^"`#
M```$CA``O(^``$*,3("9CP``!(X)^"`#!`!2C!``O(\```2.3("9CPGX(`-E
M`%&0!`!"C'\`,3(0`$*,$`"\C_\!0C#`$0(`)8@B`@(`4:9,@)F/"?@@`P``
M!(X0`+R/@`!"C$R`F8\```2."?@@`P0`48P0`+R/0``%/+R`F8^$7Z4D(3``
M``GX(`,A($``$`"\CP``!(Y,@)F/"?@@`QP`(JX0`+R/@`!"C$R`F8\```2.
M"?@@`P0`48P0`+R/N`1"C```!(Y,@)F/"?@@`R``(JX0`+R/@`!"C$R`F8\`
M``2."?@@`P0`48S\`$*,)P!`$!``O(],@)F/"?@@`P``!([\`$*,$`"\CW``
M0HQ,@)F/```$C@GX(`,D`"*N@`!"C!``O(\$`$*,```$CDR`F8\)^"`#*`!`
MK(``0HP0`+R/!`!"C```!(Y,@)F/"?@@`Q@`0*P0`+R/```$CDR`F8^``$*,
M"?@@`P0`4(R(`D*,+``"KB0`OX\@`+*/'`"QCQ@`L(\(`.`#*`"])T8-$`@A
M$```0@`</-C_O2<P()PG'`"PKR2!D(\D`+^O(`"QKQ``O*],@)F/(8B```GX
M(`,```2.$`"\CP,`!"1(@)F/(2@@`@GX(`,(`48D!P!`$!``O(\D`+^/(`"Q
MCQP`L(\A$```"`#@`R@`O2=,@)F/"?@@`P``!(X@`4*,`$`#)`#P0C`)`$,0
M$`"\CTR`F8\)^"`#```$CB`!0HP`H`,T`/!",.O_0Q00`+R/A("9CR$@(`()
M^"`#`@`%)"0`OX\@`+&/'`"PCP$`0BP(`.`#*`"])T(`'#S([[TG,""<)R@0
MLJ]$@9*/,!"TKRP0LZ\@$+"O$`"\KS00OZ\D$+&O``!"CA"!F8\<`+`G(9B`
M`$``!#PAH*``#%R$)"$H``+_#P8D'!"BKPGX(`,E""``)@!`&!``O(___U$D
M(1@1`@``8X`?`&`0G("9CR&(0``A(``"+P`%)`GX(`,A,"`"&@!`$!``O(\D
M@8*/3("9CPGX(`,``$2,$`"\CR$@0`!P@)F/(2A@`B$P``()^"`#(3@@`A``
MO(\<$*./``!"CA8`8A0T$+^/,!"TCRP0LX\H$+*/)!"QCR`0L(\(`.`#.!"]
M)^+_(!8E""``)(&"CTR`F8\)^"`#``!$C!``O(\A($``#(&9CR$H8`()^"`#
M(3"``LT-$`@0`+R/+(&9CPGX(`,E""``0@`</#`@G"?@_[TG)(&"CQP`OZ\0
M`+RO3("9CPGX(`,``$2,$`"\CQP`OX]```4\00`'/#R!AH^T@)F/(2!``!Q<
MI23$F^<D"``@`R``O2="`!P\V/^])S`@G"<@`+"O)(&0CR0`OZ\8`+RO3("9
MCPGX(`,```2.Z0T0#"$@0``8`+R/3("9CPGX(`,```2.&`"\CT``!SR$7^<D
MB("9CT``!3Q```8\$`"GKQ0`H*\A($``.%RE)`GX(`,H4,8D)`"_CR``L(\(
M`.`#*`"])T(`'#S`W[TG,""<)S0@L:]$@9&//""_KS`@L*\8`+RO.""RKP``
M(H[T@)F/+""BKPGX(`,D`+`G&`"\CQ``HJ]```(\7%Q")#B`F8]```<\%`"B
MKR$@``(!``4D`1`&)`GX(`-07.<D(`!`!!@`O(\0@9F/*!"R)R$@``(A*$`"
M"?@@`P`0!B0A@$``%P!`!!@`O(_H@)F/"?@@`P$`1"02`$`0&`"\CTB!F8\A
M,``"(2!```GX(`,A*$`"(8!0`!@`O(\```"B+""DCP``(XX(`(,4/""_CS@@
MLH\T(+&/,""PCP@`X`-`(+TG3PX0""$0```L@9F/"?@@`R4((``=#A`()0@@
M`$(`'#PP()PGJ.^])T2!@X]4$+^O.!"RKS00L:\P$+"O(`"\KU`0OJ],$+>O
M2!"VKT00M:]`$+2O/!"SKP``8HPA@(``0``$/&1<A"0AB*``*`"E)RP0HJ]%
M"Q`,)0@@`"``O(\A(``"T("9CR\`!20)^"`#(9!``!<`0!`@`+R/0``$/'!<
MA"3%"Q`,(2@``B``O(\A$``"1(&%CRP0I(\``*.,<P"#%%00OX]0$+Z/3!"W
MCT@0MH]$$+6/0!"TCSP0LX\X$+*/-!"QCS`0L(\(`.`#6!"])\B`F8\)^"`#
M(2```B``O(]``!0\@("9CR$@(`*`7(4F"?@@`R&X0``A\$``WO]`$"``O(]`
M`!8\0``5/(Q<UB:$7+4F``#"@P(`0!1```4\8%R^)`8`0!)D@9F/(2!``@GX
M(`,A*,`#,P!`$"``O(_(@)F/"?@@`R$@P`,A&,(#__]D@"$P0``O``(D!P""
M%"``O(\O``@D__]@H/__8R3__V>`_/_H$/__QB0!`.(F(3!&```0QBB[_\`0
M.("9CRP`L2<!``4D`!`&)"$XH`(A("`"$`"^KQ0`MJ\D@9./"?@@`Q@`L*\@
M`+R/3("9CPGX(`,``&2.(`"\CP,`!"10@)F/(2@@`@GX(`,(`48D"0!`%"``
MO(],@)F/"?@@`P``9(X@`4*,`(`#-`#P0C`*`$,0(`"\CX"`F8\A(```"?@@
M`X!<A28A\$``O?]`%"``O(^`#A`(0``$/(2`F8\A("`""?@@`P$`!23R_T`4
M(`"\CT``!#QP7(0DQ0L0#"$H(`(@`+R/J("9CPGX(`,A("`"A0X0""``O(\L
M@9F/"?@@`R4((````(6`"`"@$"$0@``!`(,D+P`&)`8`IA`E""````!E@/S_
MH!0!`&,D"`#@`R4((``&#Q`((1!@`$(`'#S8_[TG,""<)QP`L*\D`+^O(`"Q
MKQ``O*\V`(`0(8"`````D8`T`"`2Z("9C\B`F8\)^"`#)0@@`/__0B0A$`("
M*Q@"`@T`8!`0`+R/``!$@"\``R0X`(,4)0@@`"H/$`@O``0D``!#@#,`9!0E
M""``__]")/O_4!0E""``&@`"$B4((``T#Q`(+P`$)```0X`%`&04)0@@`/__
M0B0K&`("^O]@%",P4``"`,(D`1!"+!L`0!!"`!$\D("9C["A)"8A*``"`0#&
M)`GX(`,`$`<D)`"_C["A(B8<`+"/(`"QCP@`X`,H`+TG+P`")!\`(A8D`+^/
MZ("9CPGX(`,"``0D!P!`$"X``R0``$.D)`"_CR``L8\<`+"/"`#@`R@`O2<D
M`+^/(`"QCQP`L(\A$```"`#@`R@`O2=A#Q`(+P`$)```0X#/_V00)0@@`/__
M0B0K&`("^O]@%"4((`#._P(6+P`$)$D/$`@O``(D(`"QCQP`L(]```0\J("9
MCXQ<A"0(`"`#*`"])T(`'#R8_[TG,""<)TP`L*]$@9"/9`"_KV``M:]<`+2O
M6`"SKU0`LJ]0`+&O$`"\KP```XY!``(\H)M")$0`HZ\@`$0D(`"C)P``2(P$
M`$>,"`!&C`P`18P0`$(D``!HK`0`9ZP(`&:L#`!EK/;_1!00`&,D``!"E$``
M!#P``&*DE`L0#)!<A"1```0\E`L0#)Q<A"1```0\E`L0#*1<A"1```0\L%R$
M))0+$`Q``!(\E`L0#+A<1"9```0\R%R$)$``$SR4"Q`,0``4/&1<9":4"Q`,
M0``5/)0+$`S47(0FE`L0#.!<I"9```0\E`L0#.Q<A"1```0\E`L0#'!<A"1`
M``0\E`L0#/A<A"1```0\!%V$))0+$`P<`+$G0``$/"$H(`)%"Q`,$%V$)`,`
M0!`A*$``Q0L0#.!<I"9```0\)%V$)$4+$`PA*"`"!`!`$$``!#PX780DQ0L0
M#"$H0`!```0\1%V$)$4+$`PA*"`"%`!`$&1<9";%"Q`,(2A``$``!3RX7$0F
MQ0L0#'1=I21$`*./```"CB$`8A00`+R/9`"_CV``M8]<`+2/6`"SCU0`LH]0
M`+&/3`"PCP@`X`-H`+TG0``$/%1=A"1%"Q`,(2@@`@8`0!`0`+R/U%R$)L4+
M$`PA*$``T0\0"$``!3Q8@)F/0``%/#$`I"=H7:4D"?@@`PH`!B3=_T`4U%R$
M)L4+$`P[`*4GT0\0"$``!3PL@9F/"?@@`R4((`!"`!P\T/^])S`@G"<D`+"O
M1(&0CR@`L:\L`+^O$`"\KP```XY"`!$\$*`BCAP`HZ___P,D"0!#$$``!#P<
M`*2/```#CA0`@Q0L`+^/*`"QCR0`L(\(`.`#,`"])]1<A"1%"Q`,&`"E)P@`
M0!`0`+R/``!"@`4`0!`E""``,`!"."L0`@`*$!`($*`BKB$0```*$!`($*`B
MKBR!F8\)^"`#)0@@`$(`'#PP()PGX/^])RB!F8\<`+^O$`"\KPGX(`,E""``
M$`"\CUB!F8\)^"`#(2!```4`0!`E""````!"C!P`OX\(`.`#(`"])S,0$`@A
M$```0@`</(#_O2<P()PG=`"WKT2!EX]X`+ZO<`"VKVP`M:]H`+2O9`"SKV``
MLJ]8`+"O?`"_KUP`L:\@`+RO``#BCD``$CQ4`**O0``"/)!=0B1``**O0``"
M/)A=0B1$`**O0``"/*!=0B1``!`\2`"BKT```CR`75(F>%T0)K1=0B1``!8\
M0``5/"&@@``X`+*O/`"PKTP`HJ]0`*"O.`"S)S0`OB>`7-8F;1`0"(1<M28A
M("`""?@@`R$H@`(C`$`0(`"\CQ(``!($`',F(9```@0`<(XA($`"10L0#"$H
MP`,AB$``!`!`$"``O(\``$*`[_]`%&B!F8\A($`"Q0L0#"$H@`($`',F\/\`
M%B``O(]4`*./``#BCBL`8A1\`+^/>`"^CW0`MX]P`+:/;`"UCV@`M(]D`+./
M8`"RCUP`L8]8`+"/"`#@`X``O2?(@)F/"?@@`R$@@`(@`+R/(2`@`LB`F8\)
M^"`#+`"BKRP`HX\@`+R/(1!B`.B`F8\)^"`#`@!$)"``O(\A($``.("9CP$`
M!23__P8D(3B@`A``M*\4`+:O&`"QKPGX(`,L`**O+`"CCR$@0`+%"Q`,(2A@
M`&D0$`@@`+R/+(&9CPGX(`,E""``0@`</!"`O2<P()PG1(&%C]A_M*_0?[*O
MS'^QK^Q_OZ_H?[ZOY'^WK^!_MJ_<?[6OU'^SK\A_L*^(_KTG*`"\KP``HXP\
M@0DT(4@]`0``(ZU```,\T%UC)$@`HZ]```,\8%QC)$P`HZ]```,\/%UC)&0`
MHZ]```,\V%UC)&@`HZ]```,\:%QC)&P`HZ]```,\__\"/.!=8R1`@08T!']%
M)"$PW0!```<\<`"CKT``$CQ``!$\0``#/.1=8R0X75(FP%TQ)B&@@``A*,4`
M9%SD)%``H*]@`+*O=`"@KU0`L:]8`*.O10L0#%P`H*\$`$`0)0@@````0X!>
M`6`4(2!``"00$`PE""``(8!``&(!0!`H`+R/R("9CPGX(`,A(``"0!`"`"@`
MO(\!`$0DZ("9CPGX(`,E""`````#@B@`O(\1`&`0(8A``$``!SPAF$``\%WU
M)````I(X@)F/(2!@`A``HJ\!``4D__\&)"$XH`()^"`#`0`0)@```H(H`+R/
M]/]`%`(`<R;__Q,\0($$-$"!!30@?W`F(2"=``1_<R8A*+T`(8"0`"&8LP`>
M$1`((2!``@0`$"8```2.$P"`$"4((`!%"Q`,(2A@`B&00`#X_T`0*`"\CP``
M0H#U_T`0)0@@`&@-$`PA($`"\?]`$"@`O(^H@)F/"?@@`R$@0`(A@$``'@!`
M%"@`O(]`@;,G"']PCAD``!(E""`````"@@L`0!0!`!(D31$0""&```"`$!(`
M(1!B`@A_4(P/```2)0@@`````H(,`$`0`0!2)F@-$`PA(``"]?]`$"@`O(^H
M@)F/"?@@`R$@``+P_T`0*`"\CTT1$`@A@$``(8```,B`F8\)^"`#(2```B@`
MO(\A("`"R("9CPGX(`,AJ$``*`"\CR$0H@($!%4DZ("9CPGX(`,A(*`"*`"\
MCR$@0``AD$``0``3/$```CP$7D(D.("9CXQ<<R9```<\`0`%)/__!B3X7><D
M$`"PKQ0`LZ\8`**O"?@@`QP`L:\H`+R/(2!``JR`F8\)^"`#P`$%)/__`R0L
M`$,0*`"\CR2!D(],@)F/"?@@`P``!(XH`+R/`P`$)$B`F8\A*$`""?@@`P@!
M1B0T`$`0*`"\CU2!@H]D@)F/``"'C@``1(Q```8\$`"RKP$`!20)^"`#C%[&
M)"@`O(\A$```/($&-$2!AX\A,-T```#$C```XXQW`H,4+(&9CW@!O2?L?[^/
MZ'^^C^1_MX_@?[:/W'^UC]A_M(_4?[./T'^RC\Q_L8_(?["/"`#@`_!_O2>@
M@)F/"?@@`R4((````$*,$0`#),__0Q`H`+R/5(&#CP``AXX``&2,9("9CT``
M!CP0`+*O%`"BKP$`!20)^"`##%[&)"@`O(^+$1`((1```$R`F8\)^"`#```$
MCB`!0HP`0`,D`/!",,;_0Q0H`+R/3("9CPGX(`,```2.*`"\CRB!F8\)^"`#
M*`%1C+W_(A8H`+R/3("9CPGX(`,```2.(`%"C,`!`R3_`4(PM?]#%"@`O(_H
M@)F/"?@@`R$@H`+__P4\0($)-"%(/0%```0\!'^E))A=A"0A*"4!10L0#"&(
M0``A($``+`)`$"@`O(^H@)F/"?@@`P``D(XA*$``7PX0#"$@``(A@$``(P)`
M$"@`O(_(@)F/"?@@`R$@``(AJ$``!`!"*!``0!0H`+R/9(&9C_S_I"9```4\
M(2`$`@GX(`-(7J4D"`!`%"@`O(\$``(DO0&B$B&H%0+[_Z."+P`")+D!8A`E
M""``^P\0#"4((``(`$`4*`"\C\"`F8\A(``""?@@`R$H```T`**O;@!`%"@`
MO(]```0\0``%/-1<A"3%"Q`,=%VE)"@`O(]``!0\]("9CPGX(`.$7Y0F*`"\
MCT``!SPX@)F/$`"RKQ0`LZ\8`**O'`"TKR$@(`(!``4D__\&)&A>YR0)^"`#
M0``5/"&````H`+R/__\6)!$`%R0X$A`(>%ZU)J"`F8\)^"`#)0@@````0HP7
M`%<4*`"\C_2`F8\)^"`#`0`0)B@`O(\0`+*O.("9CQ0`LZ\8`**O'`"PKR``
MM*\A("`"`0`%)/__!B0)^"`#(3B@`B@`O(^L@)F/(2`@`@GX(`/``04DY?]6
M$"@`O(],@9F/"?@@`R$@0`)```4\9%RD),4+$`PA*"`".!`0#"$@(`(H`+R/
MBQ$0""$0(`(X$!`,,`"BKR@`O(\P`**/J("9CPGX(`,A($``BQ$0""@`O(__
M_P(\0($#-`1_520A&'T`(2`@`@$`$R0AJ'4`81(0"$"!L2>`$!,`(1`B`A1_
M1(P.`(`0`0!S)D4+$`PA**`"^/]`$"@`O(\``$.`]?]@$*B`F8\)^"`#(2!`
M`/'_0!`H`+R/\A`0""&`0`!``!`\#0`$)/@0$`C(71`F^("9CP(`%B3N_P8D
M__\')"$@0``)^"`#$`"VK___$#PH`+R/0($&-"$PW0#\?Q0F(:#4`&"!F8\T
M`*2/(2B``@GX(`,&``8D/`&BDP4`0!0H`+R//0&BDT,``R16`4,0/@&DD_B`
MF8\T`*2/(3@``!``H*\)^"`#(3```$5G!#P!(X0T>`"DK\WO!#R)JX0T@`"D
MK[J8!#PA*```_MR$-'P`I:^(`*2O(2@``#(0!#S__P<\=E2$-$"!"32$`*6O
M(2@``"%(/0$X?^LDC`"EKY``I*\A*```TL,$//#AA#3\?^PD(:`K`90`I:\A
M*```F`"DKYP`I:\A(```(2@``"&P+`$H`+R/.`"))J``I*^D`*6OJ`"DKZP`
MI:_P`*"O.`"IKSP`L:]@@9F/-`"DCR$HP`()^"`#`(`&-"&H0``H`+R/:`!`
M&/__$#R@`**/I`"DC\`H%0##1Q4`7`"`%"$HH@`K$*(`6@!`%*@`HX^H`**/
MK`"DC\`P"`!"'Q4`)1C#`"$80P!"-P@`(3"&`"L08@#P`*2/(1!&`*``I:^D
M`*"OJ`"CKT<`@!"L`**O0``")",01``J&%4``@!@$"&`H`(A@$``2(&9CS@`
MA"0A((0"(2C``@GX(`,A,``"\`"BCT```R0A$`("*`"\C\W_0Q3P`**O=`80
M#"$@@`(H`+R/(ZBP`B&`T`)``*(J)0!`%."`F8\A\*`"(8@``D"!MR<A&"`"
M<'_G)D``*B8#`&F(!P!HB`L`98@/`&2(``!IF`0`:)@(`&68#`!DF!``8R0`
M`.FL!`#HK`@`Y:P,`.2L\O]J%!``YR3`_]XG(2"``G0&$`PAB&``0`#"*^C_
M0!`H`+R/P/^U)H(1%0`!`$,D@!D#`(`1`@`A@`,"(ZBB`N"`F8\X`*2/(2@`
M`B$PH`()^"`#2``')"@`O(^\$A`(\`"UK_42$`@A@,`"J`"CCZP`IH\!`&(D
M*QA#`-`2$`@A(&8`1("9CS0`I(\)^"`#/`"QCZ``MH]`@:0GPA@6`#\`8S`!
M`&(D(2B#`#D`0BB`_P0D*`"\CZ@`MX^)`$`0<'^DH$"!!#0A()T`.'\")B$0
M@@"P@)F/.0!D)#<`!B0A($0`(2@```GX(`,C,,,`__\4/$"!"31`@;4G`D87
M``(\%P`",A<``BX6``(<%@`"$A8`(4@]`3A_A"8A("0!J'^HHJE_IZ*J?Z:B
MJW^WHJQ_I:*M?Z.BKG^BHG0&$`RO?[:B6'^CCE!_I(X"/`,`.'^HCD!_IHY(
M?Z6.`DH$`#0`IZ]`@0<T*`"\CR$X_0#0?Y`FRG^IHC0`J8\"M`8`(8#P`"&@
M]``"%@@``LP(``+""``"O@8``GH&``)V!0`";`4``F(%``)>!``"5`0``OX#
M``+R`P!```<\P7^VHKQ_HJ*]?[FBOG^XHK]_J*+`?[>BPG^OHL-_IJ+$?ZZB
MQ7^MHL9_K*+'?Z6BR'^KHLE_JJ++?Z2BS'^_HLU_J:+.?[ZBSW^CHKU_E"8H
M`!4FDQ,0"/!=]B0``(*2`0"4)CB`F8\A(``"$`"BKP$`!23__P8D(3C``@GX
M(`,"`!`F]?\5%B@`O(___P(\0($$--!_0R0A()T`(1B#`!@`HZ]```,\.("9
MCX1?8R1```<\$`"RKQ0`LZ\<`*.O(2`@`@$`!23__P8D6%[G)`GX(`,X`:"C
M/A(0""@`O(\$`)2.1OZ`$LB`F8\)^"`#(2"``@0`0RQ!_F`4*`"\C_S_1"1D
M@9F/0``%/"$@A`()^"`#4%ZE)#G^0!0E""``^A$0""&`@`)`@0(T(1!=`#A_
M$"8A@%``.0!D)+"`F8\_``8D(2`$`B$H```)^"`#(S##`'0&$`PA(``".```
MKCP``*Y```"N1```KD@``*Y,``"N4```KE0``*Y8``"N7```KF```*YD``"N
M:```KD<3$`AL``"N00`#)*K^@Q3X@)F//P&CDZ?^8A1``:.32``")*3^8A1!
M`:.310`")*'^8A0T`*2/__\'),;_!B0)^"`#$`"VKR@`O(\T`*2/8(&9CR$H
M@`()^"`#*0`&)"@`O(]```(\A%]")#B`F8]```<\$`"RKQ0`LZ\8`+2O'`"B
MKR$@(`(!``4D__\&)`GX(`-87N<D/A(0""@`O(_D$1`(``"0C@GX(`,E""``
M0@`</#`@G">P_[TG1(&#CQ``O*],`+^O,`"RKT@`OJ\D@9*/1`"WKT``MJ\\
M`+6O.`"TKS0`LZ\L`+&O*`"PKP``8HQ,@)F/(`"C)P``1(X<`*.O)`"BKPGX
M(`,E""```0`#)$``!#QA`$.@N%R$)$4+$`P@`*4G!0!`$!``O(\``$2`,0`#
M)-(`@Q`E""``<`\0#"4((``0`+R/3("9CPGX(`,``$2.$`"\CT``!3SD@)F/
M(2!``.!>I20!``8D"?@@`PL`!R1&`$`0$`"\CT(`$SRXL6..$`!$C`(`8BA`
M`$`4&`"4C"``%3PAB````0`0)$(`%SP`!+4F5A00"``$%B1D@9F/$`!%C`GX
M(`,A(,`#+P!`%!``O(^XL6*.`0`0)BH8`@(K`&`0`0`Q)DR`F8\)^"`#``!$
MCA``O(\A,"`"?("9CR$@0``A*(`""?@@`R$X```A,$``'0!`$!``O(\``$*,
MM+'EC@@`0XR`(!``(2"D`"08=0#A_W80``">C"2!@H],@)F/``!$C`GX(`,8
M`*:O$`"\CQ@`IH\(@9F/``#%C"$@0``A,```"?@@`P(`!R00`+R/(2A``&2!
MF8\)^"`#(2#``]/_0!`0`+R/N+%BCO__0R1L`'$0`@!"*$R`F8\D@9&/"?@@
M`P``1(X0`+R/0``%/.2`F8\A($``Z%ZE)`$`!B0)^"`#`P`')"&`0``3`$`0
M$`"\CTR`F8\)^"`#```DCA``O(\0``..0``&/`R!F8\``&6,(2!```GX(`/L
M7L8D$``"CD```SP``$*,"`!"C"000P"M`$`4$`"\CTR`F8\D@9./"?@@`P``
M1(X0`+R/0``%/.2`F8\A($``]%ZE)`$`!B0)^"`#`P`')"&(0``4`$`0$`"\
MCT``!#QP7(0D10L0#"``I2<0`+R/(8!`````9(YO`$`03("9CPGX(`,E""``
M$`"\CQ``(XX,@9F/``!EC"$@0``)^"`#(3```A``O(],@)F/``!$C@GX(`-"
M`!,\0``$/&$`0*!D7(0D10L0#"``I2<A@$``$`"\CS(`0!"\L6*NK("9CR$@
M0``)^"`#P`$%)!$``R0%`$,0$`"\CP$`0R0"`&,LA0!@$$(``SQ$@82/)`"C
MCP``@HQ]`&(43`"_CT@`OH]$`+>/0`"VCSP`M8\X`+2/-`"SCS``LH\L`+&/
M*`"PCP@`X`-0`+TGE/]`%`$`$"1,@)F/``!$C@GX(`,!`!`F$`"\CR$@0`!`
M@9F/"?@@`R$H@`*XL6*.*A`"`O3_0!00`+R/A!00"$R`F8\!`$*`,?]`$$R`
MF8\N%!`()0@@`$(`$#RM$!`,M+$$CKRQ8JY2`$`0$`"\CQ``(HX@``,\``!$
MC``$8R0(`(*,)!!#```$`R0P`$,4)(&"CQ``A(RTL1".%(&9CPGX(`,A*``"
M$``CCB``!#P``&:,``2$)`@`PXPAF$``)!AD```$`B00`+R/$@!B%```$(X0
M`,:,0``$/+B`F8\<7X0D(2@``@GX(`,A.&`""?@@`R4((`!"``(\$``CCK2Q
M0HP``&2,G`T0#```18S&%!`($`"\CTR`F8\)^"`#``!$CA``O(\0`".."(&9
MCP``98PA,```(2!```GX(`,"``<D(3!``"05$`@0`+R/3("9CPGX(`,``$2,
M$`"\CQ``(XX(@9F/``!EC"$@0``A,```"?@@`P(`!R0A($``%!40"!``O(],
M@)F/"?@@`P``)(X0`+R/$``#CI2`F8\``&6,"?@@`R$@0`"D%!`($`"\CT``
M!#RX@)F/"?@@`_A>A"0L@9F/"?@@`R4((`"TL6.,0``$/```98RX@)F/1%^$
M)"$P``()^"`#(3A``$(`'#S8_[TG,""<)R``L:\<`+"O)`"_KQ``O*\-#Q`,
M(8B`````18`(`*`0(8!```$`0R0O``8D&`"F$"4((````&6`_/^@%`$`8R3[
M#Q`,)0@@``P`0!`0`+R/"P`@$B0`OX\``"*""`!`$&B!F8]```4\(2```@GX
M(`,$7J4D"``"$A``O(\D`+^/(`"QCQP`L(\(`.`#*`"])WH5$`@A@&``)`"_
MCQP`L(\A("`"(`"QCW(,$`@H`+TG0@`</.#_O2<P()PG&`"PKR2!D(\<`+^O
M$`"\KTR`F8\)^"`#```$CA``O(\A($```(&9CPGX(`/__P4D$`"\CTR`F8\)
M^"`#```$CA``O(\<`+^/&`"PCT``!3Q@@)F/(2!``-PSI20A,```"``@`R``
MO2<E""``)0@@``(`'#Q0R9PG(>"9`RB`@H\%`$`0)0@@````1XS\@)F/"``@
M`R4((`#\_P`0(3@```(`'#P@R9PG(>"9`\C_O2<L@)F/$`"\KS``M:\L`+2O
M*`"SKR0`LJ\@`+&O-`"_KQP`L*\AF(``(:"@``GX(`,AJ,``$`"\CS"`D8\T
M@)*/(Y!1`H.0$@`)`$`2(8``````.8XA(&`"(2B``B$PH`()^"`#`0`0)OG_
M$A8$`#$F-`"_CS``M8\L`+2/*`"SCR0`LH\@`+&/'`"PCP@`X`,X`+TG"`#@
M`R4((``E""``$("9CR%XX`,)^"`#<0`8)!"`F8\A>.`#"?@@`W``&"00@)F/
M(7C@`PGX(`-O`!@D$("9CR%XX`,)^"`#;0`8)!"`F8\A>.`#"?@@`VL`&"00
M@)F/(7C@`PGX(`-J`!@D$("9CR%XX`,)^"`#:0`8)!"`F8\A>.`#"?@@`V<`
M&"00@)F/(7C@`PGX(`-E`!@D$("9CR%XX`,)^"`#9``8)!"`F8\A>.`#"?@@
M`V,`&"00@)F/(7C@`PGX(`-B`!@D$("9CR%XX`,)^"`#80`8)!"`F8\A>.`#
M"?@@`U\`&"00@)F/(7C@`PGX(`->`!@D$("9CR%XX`,)^"`#7``8)!"`F8\A
M>.`#"?@@`UL`&"00@)F/(7C@`PGX(`-:`!@D$("9CR%XX`,)^"`#60`8)!"`
MF8\A>.`#"?@@`U@`&"00@)F/(7C@`PGX(`-7`!@D$("9CR%XX`,)^"`#5@`8
M)!"`F8\A>.`#"?@@`U4`&"00@)F/(7C@`PGX(`-4`!@D$("9CR%XX`,)^"`#
M4P`8)!"`F8\A>.`#"?@@`U(`&"00@)F/(7C@`PGX(`-1`!@D$("9CR%XX`,)
M^"`#4``8)!"`F8\A>.`#"?@@`T\`&"00@)F/(7C@`PGX(`--`!@D$("9CR%X
MX`,)^"`#2P`8)!"`F8\A>.`#"?@@`TH`&"00@)F/(7C@`PGX(`-)`!@D$("9
MCR%XX`,)^"`#2``8)!"`F8\A>.`#"?@@`T<`&"00@)F/(7C@`PGX(`-&`!@D
M$("9CR%XX`,)^"`#10`8)!"`F8\A>.`#"?@@`T0`&"00@)F/(7C@`PGX(`-#
M`!@D$("9CR%XX`,)^"`#0@`8)!"`F8\A>.`#"?@@`T$`&"00@)F/(7C@`PGX
M(`,_`!@D$("9CR%XX`,)^"`#/@`8)!"`F8\A>.`#"?@@`ST`&"00@)F/(7C@
M`PGX(`,\`!@D$("9CR%XX`,)^"`#.P`8)!"`F8\A>.`#"?@@`SH`&"00@)F/
M(7C@`PGX(`,Y`!@D$("9CR%XX`,)^"`#.``8)!"`F8\A>.`#"?@@`S<`&"00
M@)F/(7C@`PGX(`,V`!@D$("9CR%XX`,)^"`#,P`8)!"`F8\A>.`#"?@@`S(`
M&"00@)F/(7C@`PGX(`,Q`!@D$("9CR%XX`,)^"`#,``8)!"`F8\A>.`#"?@@
M`R\`&"00@)F/(7C@`PGX(`,M`!@D$("9CR%XX`,)^"`#*P`8)!"`F8\A>.`#
M"?@@`RH`&"00@)F/(7C@`PGX(`,I`!@D$("9CR%XX`,)^"`#*``8)!"`F8\A
M>.`#"?@@`R<`&"00@)F/(7C@`PGX(`,F`!@D$("9CR%XX`,)^"`#)0`8)```
M```````````````````"`!P\8,2<)R'@F0/@_[TG$`"\KQP`OZ\<`+^/"`#@
M`R``O2<````````````````!``(`)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!
M4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,
M3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````3$E"4$%42`!,1%],
M24)205)97U!!5$@`3$E"4D%265]0051(`````$193$1?3$E"4D%265]0051(
M````4TA,24)?4$%42```55-%4@````!365-414T``"]T;7``````5$5-4$1)
M4@!435``55-%4DY!344`````)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@`````8````
M<&5R;``````P````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`[
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!
M4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]
M+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%2
M1U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L(#(["G)E
M860@7T9(+"`D8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP
M;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E
M96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L
M("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q
M=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B
M)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP
M9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*
M<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL
M96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA
M;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F
M.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@
M/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U
M="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U
M9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T
M('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!
M3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F
M:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I
M9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE
M;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`````````````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````<&5R;'AS:2YC````````````\$$``(#____/00``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'09
M0``\&4````````````````````````````#_____````````````````D%]`
M````````````````````````````````````````````````@$`50``05T``
MM%=``.!60`"<H4$`!!5``/2?00#XGT$`L%M``*!;0`"06T``@%M``'!;0`!@
M6T``4%M```````!`6T```````#!;0``@6T``$%M```!;0`#P6D``````````
M``#@6D``T%I``,!:0`"P6D``H%I``)!:0`"`6D``<%I``&!:0`!06D``````
M`$!:0``P6D``(%I``!!:0```6D``\%E``.!90`#064``P%E``+!90`"@64``
M`````)!90```````@%E``'!90`!@64``4%E``$!90``P64``(%E``!!90```
M64``\%A``.!80`#06$``P%A``+!80```````H%A``)!80```````@%A``'!8
M0`!@6$``4%A``$!80```````,%A````````@6$``$%A```!80```````\%=`
M``````#@5T``T%=``,!70```````1T-#.B`H1&5B:6%N(#0N.2XR+3$P*2`T
M+CDN,@!'0T,Z("A$96)I86X@-"XX+C0M,2D@-"XX+C0`````T!E``````X#\
M____``````````"P`@``'0```!\````4+4````!_@/S___\``````````#@`
M```=````'P```%`N0`````^`_/___P``````````.````!T````?````%"]`
M````_X#\____``````````!(````'0```!\```#(,4````#_P/S___\`````
M`````/`````=````'P```-PS0`````>`_/___P``````````*````!T````?
M````H#5``````X#\____```````````H````'0```!\```!P-D`````?@/S_
M__\``````````#@0```=````'P```*0W0`````"`_/___P``````````(```
M`!T````?````]#=``````8#\____```````````H````'0```!\```!T.$``
M```'@/S___\``````````$`@```=````'P```'0Y0```````````````````
M`````````!T````?````?#E`````_\#\____``````````!8$```'0```!\`
M``#\.T`````````````````````````````=````'P```#0\0`````.`_/__
M_P``````````*````!T````?````P#U`````/X#\____``````````!H````
M'0```!\```#L/T`````#@/S___\``````````#`````=````'P```)!`0```
M``"`_/___P``````````(````!T````?````X$!`````_\#\____````````
M``"`````'0```!\```"T0D````#_P/S___\``````````&B!```=````'P``
M`"A00````/_`_/___P``````````4````!T````?````J%5``````X#\____
M```````````H````'0```!\```!D5D`````!@/S___\``````````"`````=
M````'P```$`50````!^`_/___P``````````2````!T````?````X%9`````
M````````````````````````'0```!\````05T`````_@/S___\`````````
M`#@````=````'P```+170````````````````````````````!T````?````
M00\```!G;G4``0<````$`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"Y-25!3+F%B:69L86=S`"YR96=I;F9O`"YN;W1E+F=N=2YB=6EL9"UI
M9``N9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N
M`"YG;G4N=F5R<VEO;E]R`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ
M8W(`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=``N
M<&1R`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````````````
M````````````````````````````````````````````"P````$````"````
ME`%``)0!```-```````````````!`````````!,````'`````@```*0!0`"D
M`0``(```````````````!``````````A````*@``<`(```#(`4``R`$``!@`
M``````````````@````8````,`````8``'`"````X`%``.`!```8````````
M```````$````&````#D````'`````@```/@!0`#X`0``)```````````````
M!`````````!,````!@````(````<`D``'`(``"@!```)``````````0````(
M````50````4````"````1`-``$0#``!4`P``"``````````$````!````%L`
M```+`````@```)@&0`"8!@``(`<```D````!````!````!````!C`````P``
M``(```"X#4``N`T``+@%``````````````$`````````:P```/___V\"````
M<!-``'`3``#D````"``````````"`````@```'@```#^__]O`@```%040`!4
M%```L`````D````#````!`````````"'`````0````8````$%4``!!4``#P`
M``````````````0`````````C0````$````&````0!5``$`5``"`0@``````
M```````0`````````),````!````!@```,!70`#`5P``$`0`````````````
M!`````````"?`````0````8```#06T``T%L``"0```````````````0`````
M````I0````$````"`````%Q```!<``#@/P`````````````0`````````*T`
M```!`````@```.";0`#@FP``!```````````````!`````````"W````#@``
M``,```#TGT$`])\```0```````````````0`````````PP````\````#````
M^)]!`/B?```$```````````````$`````````,\````!`````P```/R?00#\
MGP``!```````````````!`````````#4`````0````,`````H$$``*```#``
M`````````````!``````````V@````$````#````,*!!`#"@```$````````
M```````$`````````.,````!`````P``$$"@00!`H```7`$`````````````
M$`````0```#H`````0````,``!"<H4$`G*$```0```````````````0`````
M````[P````@````#````H*%!`*"A```P$``````````````0`````````/0`
M```!````,`````````"@H0``.0```````````````0````$```#]`````0``
M````````````W*$``&`#``````````````0``````````@$``/7__V\`````
M`````#RE```0```````````````!`````````!(!```!``````````````!,
MI0```````````````````0`````````!`````P``````````````3*4``"`!
2``````````````$`````````
